@@ -39,8 +39,10 @@
 #' @slot fitted The fitted values of the model. This is a vector.
 #' @slot residuals The residuals of the model. This is a vector.
 #' @slot df.residual The degrees of freedom of the model.
-#' @slot r.squared Coefficient of determination of the model.
-#' @slot adj.r.squared Adjusted coefficient of determination.
+#' @slot sigma The residual standard deviation of the model.
+#' @slot limit The scalability limit as per Amdahl.
+#' @slot peak A vector with the predictor and response values of the peak.
+#' @slot optimal A vector with the optimal predictor and response values.
 #' @slot efficiency The efficiency, e.g. speedup per processor.
 #' @slot na.action The \code{na.action} used by the model.
 #'
@@ -59,14 +61,14 @@ setClass("USL",
                         fitted        = "vector",
                         residuals     = "vector",
                         df.residual   = "integer",
-                        r.squared     = "numeric",
-                        adj.r.squared = "numeric",
+                        sigma         = "numeric",
+                        limit         = "numeric",
+                        peak          = "vector",
+                        optimal       = "vector",
                         efficiency    = "vector",
                         na.action     = "character"),
          prototype(coef.names    = c("alpha", "beta", "gamma"),
                    df.residual   = 0L,
-                   r.squared     = 0,
-                   adj.r.squared = 0,
                    na.action     = "na.omit"),
          validity = function(object) {
            err <- character()
@@ -81,15 +83,5 @@ setClass("USL",
              err <- c(err, msg)
            }
 
-           if ((object@r.squared < 0) || (object@r.squared > 1)) {
-             msg <- "r.squared must be 0 <= r.squared <= 1"
-             err <- c(err, msg)
-           }
-
-           if ((object@adj.r.squared < 0) || (object@adj.r.squared > 1)) {
-             msg <- "adj.r.squared must be 0 <= adj.r.squared <= 1"
-             err <- c(err, msg)
-           }
-
            if (length(err) == 0) return(TRUE) else return(err)
          })
