@@ -28,14 +28,19 @@ setGeneric("print", function(x, ...) standardGeneric("print"))
 setGeneric("predict", function(object, ...) standardGeneric("predict"))
 setGeneric("summary", function(object, ...) standardGeneric("summary"))
 setGeneric("confint", function(object, parm, level) standardGeneric("confint"))
+setGeneric("sigma", function(object, ...) standardGeneric("sigma"))
 
 #
 # USL specific methods
 #
 setGeneric("scalability",
-           function(object, alpha, beta) standardGeneric("scalability"))
+           function(object, alpha, beta, gamma) standardGeneric("scalability"))
+setGeneric("optimal.scalability",
+           function(object, alpha, beta, gamma) standardGeneric("optimal.scalability"))
 setGeneric("peak.scalability",
-           function(object, alpha, beta) standardGeneric("peak.scalability"))
+           function(object, alpha, beta, gamma) standardGeneric("peak.scalability"))
+setGeneric("limit.scalability",
+           function(object, alpha, beta, gamma) standardGeneric("limit.scalability"))
 setGeneric("efficiency",
            function(object) standardGeneric("efficiency"))
 setGeneric("overhead",
